@@ -46,7 +46,7 @@
 #define CHECK(cond) if(!(cond)) { fprintf(stderr, "INTERNAL ERROR in %s, line %u: condition %s is not satisfied!\n", __FILE__, __LINE__, #cond); abort(); }
 #endif
 
-#if NDEBUG != 0
+#if defined(SIM_IMPORT) || defined(OMNETPPLIBS_IMPORT)
 #define OPP_CHECK(cond) if(!(cond)) { throw new cException("INTERNAL ERROR in %s, line %u: condition %s is not satisfied!\n", __FILE__, __LINE__, #cond); }
 #else
 #define OPP_CHECK(cond) if(!(cond)) { fprintf(stderr, "INTERNAL ERROR in %s, line %u: condition %s is not satisfied!\n", __FILE__, __LINE__, #cond); abort(); }
